@@ -28,6 +28,7 @@ define(PROON_PRE_DATE, 'date_');
 define(PROON_PRE_SIZE, 'size_');
 define(PROON_PRE_COUNT, 'count_');
 define(PROON_PRE_UNSEEN, 'unseen_');
+define(PROON_PRE_MANUAL, 'manual_');
 define(PROON_PRE_SHOW_EFFECT, 'effect_');
 define(PROON_PRE_PRUNE_THIS, 'now_');
 define(PROON_PRE_OPTION, 'proon_');
@@ -37,12 +38,9 @@ define(PROON_ANCHOR_FOLDERS, 'fldrs');
 define(PROON_ANCHOR_HELP, 'help');
 define(PROON_ANCHOR_BOTTOM, 'bot');
 
-define(PROON_F_DATES, 'dates');
-define(PROON_F_SIZES, 'sizes');
-define(PROON_F_COUNTS, 'counts');
 define(PROON_F_DATE_OR_SIZE_OR_COUNT, 'dateorsizeorcount');
-define(PROON_F_UNSEENS, 'unseens');
-define(PROON_P_OPTIONS, 'opts');
+define(PROON_P_OPTIONS, 'useropts');
+define(PROON_P_SITE, 'siteopts');
 define(PROON_P_PREFS_SEEN, 'prefs_seen');
 
 // These are preference item names.  If they change,
@@ -51,7 +49,10 @@ define(PROON_O_F_DATE_SPAN, 'proon_folder_datespans');
 define(PROON_O_F_SIZE_SPAN, 'proon_folder_sizespans');
 define(PROON_O_F_COUNT_SPAN, 'proon_folder_countspans');
 define(PROON_O_F_TOSS_UNSEEN, 'proon_folder_toss_unseen');
+define(PROON_O_F_MANUAL_ONLY, 'proon_folder_manual_only');
 define(PROON_O_U_PRUNE_INTERVAL, 'proon_user_prune_interval');
+define(PROON_O_U_LOGIN_N, 'proon_user_login_prune_frequency');
+define(PROON_O_U_LOGIN_COUNT, 'proon_login_count'); // not a user-settable preference
 define(PROON_O_U_VIA_TRASH, 'proon_user_via_trash');
 define(PROON_O_U_TRASH_TIME, 'proon_user_trash_time');
 define(PROON_O_U_UNSUBSCRIBED, 'proon_user_unsubscribed');
@@ -93,4 +94,8 @@ define(PROON_SPAN_DATE, 'date');
 define(PROON_SPAN_SIZE, 'size');
 define(PROON_SPAN_COUNT, 'count');
 
+define(SYTa, '<small><i>');
+define(SYTz, '</i></small>');
+define(SYTCH, '<small><input type="checkbox" name="" value="" disabled checked></small>');
+
 ?>
